==> teamapps-client-0.9.64.zip: tsd/modules/DefaultTeamAppsUiContext.d.ts <==
import { TeamAppsUiContextInternalApi } from "./TeamAppsUiContext";
import { UiConfigurationConfig } from "../generated/UiConfigurationConfig";
import { UiComponentConfig } from "../generated/UiComponentConfig";
import { UiEvent } from "../generated/UiEvent";
import { UiCommand } from '../generated/UiCommand';
import { TemplateRegistry } from "./TemplateRegistry";
import { TeamAppsEvent } from "./util/TeamAppsEvent";
import { UiClientObject } from "./UiClientObject";
import { UiClientObjectConfig } from "../generated/UiClientObjectConfig";
export declare class DefaultTeamAppsUiContext implements TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    readonly sessionId: string;
    isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private components;
    private _executingCommand;
    private connection;
    constructor(webSocketUrl: string, clientParameters?: {
        [key: string]: string | number;
    });
    get executingCommand(): boolean;
    fireEvent(eventObject: UiEvent): void;
    registerClientObject(clientObject: UiClientObject, id: string, teamappsType: string): void;
    createClientObject(config: UiClientObjectConfig): UiClientObject;
    refreshComponent(config: UiComponentConfig): void;
    destroyClientObject(id: string): void;
    getClientObjectById(id: string): UiClientObject;
    private replaceComponentReferencesWithInstances;
    private commandExecutor;
    private executeCommand;
}

==> teamapps-client-0.9.82.zip: tsd/modules/DefaultTeamAppsUiContext.d.ts <==
import { TeamAppsUiContextInternalApi } from "./TeamAppsUiContext";
import { UiConfigurationConfig } from "../generated/UiConfigurationConfig";
import { UiComponentConfig } from "../generated/UiComponentConfig";
import { UiEvent } from "../generated/UiEvent";
import { UiCommand } from '../generated/UiCommand';
import { TemplateRegistry } from "./TemplateRegistry";
import { TeamAppsEvent } from "./util/TeamAppsEvent";
import { UiClientObject } from "./UiClientObject";
import { UiClientObjectConfig } from "../generated/UiClientObjectConfig";
import { UiWindow } from "./UiWindow";
export declare class DefaultTeamAppsUiContext implements TeamAppsUiContextInternalApi {
    private static logger;
    readonly onStaticMethodCommandInvocation: TeamAppsEvent<UiCommand>;
    readonly sessionId: string;
    isHighDensityScreen: boolean;
    config: UiConfigurationConfig;
    readonly templateRegistry: TemplateRegistry;
    private components;
    private _executingCommand;
    private connection;
    private commandExecutor;
    private expiredMessageWindow;
    private errorMessageWindow;
    private terminatedMessageWindow;
    constructor(webSocketUrl: string, clientParameters?: {
        [key: string]: string | number;
    });
    get executingCommand(): boolean;
    fireEvent(eventObject: UiEvent): void;
    registerClientObject(clientObject: UiClientObject, id: string, teamappsType: string): void;
    createClientObject(config: UiClientObjectConfig): UiClientObject;
    refreshComponent(config: UiComponentConfig): void;
    destroyClientObject(id: string): void;
    getClientObjectById(id: string): UiClientObject;
    private replaceComponentReferencesWithInstances;
    private executeCommand;
    setSessionMessageWindows(expiredMessageWindow: UiWindow, errorMessageWindow: UiWindow, terminatedMessageWindow: UiWindow): void;
}
